/****************************************************************************
 *
 *      Copyright (c) 2000, 2001 Micro Focus International Ltd.
 *
 *      CCI Trace Front Layer template Header File
 *
 *      Source Module ccipackn.h
 *
 *      Sccs Identification  @(#)ccipackn.h $Revision: 1.17 $
 *
 *      $Modtime:   Aug 22 2001 17:31:58  $
 *
 ****************************************************************************/

#ifndef H_CCIPACKN
#define H_CCIPACKN
static char ccipackn_h_sccsid[] = "@(#)   ccipack1.h $Revision: 1.17 $"; 
#endif

/** Start of source module ccipackn.h **/

/* 

   This file contains a simple statement to alter the byte packing level of
   the compiler from the point of inclusion of this file onwards.

   When used with ccipack1.h this file is used to pack the intervening
   structure definitions as single byte aligned strutures for passing to
   COBOL or shippping on the wire to another system.

   The statements in this file set the byte packing to default byte alignment
   for the system that it is being used upon.

 */

 /****************************************************************************
 * Revision History
 *
 * $Log: ccipackn.h,v $
 * Revision 1.17  2007/11/02 16:18:45  spe
 * Limit the CPU6000 definition to try and only catch PIM's master.h definition
 * of an AIX PowerPC. The Imake portkit uses RS6000 to do this, but Paul's
 * master.h which runs in the test suite uses CPU6000 plus a system ID tag.
 * We need to catch both.
 * This change should match the change to ccipack1.h v1.16
 *
 * Revision 1.16  2007/11/02 15:40:50  spe
 * Add sccsid to make it easier to track when changes make it into binary modules
 *
 * Revision 1.15  2007/09/10 15:23:01  garyst
 * Change previous CVS commit comment formating.
 *
 * Revision 1.14  2007/09/10 15:21:44  garyst
 * Made changes for AIX, where the master.h defines CPU6000 for AIX not RS6000,
 * so added this to the if statement as an extra OR clause.
 *
 * Revision 1.13  2007/07/26 14:55:57  hps
 * Fix RPI "546096 casstart on HP Itanium gives "no licenses found.""
 *
 *  - HP/UX on IA64 is apparently our first ALIGN16 platform. Add check for
 * ALIGN16 in "ccipack" headers so that #pragma pack is used as expected.
 *
 * Revision 1.12  2007/03/06 16:06:44  mww
 * Use actual working XL C pragmas on AIX, not the ones that the XL C docs
 * claim will work (but don't).
 *
 * Revision 1.11  2007/03/04 20:46:44  mww
 * Suport AIX (replacing "-qalign=packed" compiler option).  See email
 * stream notestream of 1-2 March 2007 for details.
 *
 * Revision 1.10  2006/01/24 18:55:05  mww
 * Merged from NX5-branch
 *
 * Revision 1.9.2.1  2006/01/09 16:38:23  spe
 * Unix portations fix. Win32/64 edit broke Unix compilations.
 *
 * Revision 1.9  2005/09/28 22:22:22  mww
 * 1056899: Enable packing pragma for WIN32.  This allows removing -Zp1 from
 * trace/makefile, which in turn fixes the WIN64 build properly.
 *
 * Revision 1.8  2005/08/08 20:33:20  hps
 * Remove toxic line breaks.
 *
 * Revision 1.7  2005/08/08 15:38:19  hps
 * WIN64 changes.
 *
 * Revision 1.6  2001/08/23 12:28:52  SPE
 * Update copyright to Micro Focus International Ltd
 * from MERANT.
 *
 * 
 *    Rev 1.5   Aug 23 2001 12:28:52   SPE
 * Update copyright to Micro Focus International Ltd 
 * from MERANT.
 * 
 *    Rev 1.4   23 Jan 2001 11:45:46   SPE
 *  
 * 
 *    Rev 1.3   07 Dec 2000 10:40:52   SPE
 * Really use correct syntax for HP_UX packing pragma this time.
 * 
 *    Rev 1.2   06 Dec 2000 17:46:06   SPE
 * Switch off use of #pragma verbs on AIX (RS600 definition).
 * 
 *    Rev 1.1   06 Dec 2000 12:02:48   SPE
 *  
 * 
 *    Rev 1.0   04 Dec 2000 15:28:06   SPE
 * ccipack1.h and ccipackn.h alter the compilers byte-packing 
 * level to single-byte and the system default value respectively.
 *
 ****************************************************************************/
 
#if defined(WIN32) || defined(WIN64) || (defined(UNIX) && !defined(HPUX1020) \
                  && (defined(ALIGN16) || \
                      defined(ALIGN8) || \
                      defined(ALIGN4)))        /* SPE 1.2 */
#  if defined HP_UX /* HP_UX below */
     /* HP has no "default" pragma pack settting */
#    if defined(ALIGN4)
#      pragma pack 4                                             /* SPE 1.3 */
#    elif defined(ALIGN8)                                        /* HPS 1.13 */
         /* if we ever get ALIGN16, stick a check here */
#      pragma pack 8                                             /* SPE 1.3 */
     /* Must be ALIGN16 - if ALIGN32 ever defined stick another check in */
#    else                                                        /* HPS 1.13 */
#      pragma pack 16                                            /* HPS 1.13 */
#    endif /* which ALIGN level? */
#  elif defined(RS6000) || (defined(CPU6000) && defined(AIX))    /* SPE 1.17 */
#    pragma options align=full                                   /* MWW 1.12 */
#  else
#    pragma pack()    /* suits most compilers */
#  endif
#endif /* UNIX and not ALIGN1 above here */
